https://issues.apache.org/bugzilla/show_bug.cgi?id=50243

--- Comment #2 from Jeff Trawick <[email protected]> 2010-11-10 07:13:59 EST 
---
line numbers have changed quite a bit since 2.3.8, but I assume this is the
issue you found:


Index: include/http_config.h
===================================================================
--- include/http_config.h    (revision 1033417)
+++ include/http_config.h    (working copy)
@@ -1000,10 +1000,10 @@
  * Merge old ap_logconf into new ap_logconf.
  * old and new must have the same life time.
  * @param old The ap_logconf to merge from
  * @param new The ap_logconf to merge into
  */
 AP_DECLARE(void) ap_merge_log_config(const struct ap_logconf *old,
-                                     struct ap_logconf *new);
+                                     struct ap_logconf *new_logconf);
@@ -1000,10 +1000,10 @@
  * old and new must have the same life time.
  * @param old The ap_logconf to merge from
- * @param new The ap_logconf to merge into
+ * @param new_logconf The ap_logconf to merge into
  */
 AP_DECLARE(void) ap_merge_log_config(const struct ap_logconf *old,


(I didn't see any other problems remaining in that file)

fixed in trunk, will be in 2.3.9

thanks!

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
------- You are receiving this mail because: -------
You are the assignee for the bug.

---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to